@@ -7,11 +7,11 @@ if test ! -d "" ; then
 fi
 
 if test ! -d "$abs_top_srcdir" ; then
-  abs_top_srcdir=/src/external-vcs/savannah/libcdio
+  abs_top_srcdir=/src/external-vcs/github/libcdio/libcdio
 fi
 
 if test ! -d "$top_builddir" ; then
-  top_builddir=/src/external-vcs/savannah/libcdio
+  top_builddir=/src/external-vcs/github/libcdio/libcdio
 fi
 
 . ${top_builddir}/test/check_common_fn
