@@ -108,7 +108,7 @@ main(int argc, const char *argv[])
 
       /* Compare the two statbufs. */
       if (p_statbuf->lsn != p_statbuf2->lsn ||
-	  p_statbuf->size != p_statbuf2->size ||
+	  p_statbuf->total_size != p_statbuf2->total_size ||
 	  p_statbuf->type != p_statbuf2->type) {
 	  fprintf(stderr, "File stat information between fs_stat and "
 		  "fs_find_lsn isn't the same\n");
@@ -147,12 +147,12 @@ main(int argc, const char *argv[])
 	  rc=7;
 	}
     exit:
-      if (psz_path != NULL)
-	free(psz_path);
       iso9660_stat_free(p_statbuf);
       iso9660_stat_free(p_statbuf2);
       iso9660_stat_free(p_statbuf3);
       cdio_destroy(p_cdio);
+      if (NULL != psz_path)
+	free(psz_path);
       exit(rc);
     }
   }
